/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.translation.internal.security.permission;

import com.liferay.exportimport.kernel.staging.permission.StagingPermission;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.translation.constants.TranslationConstants;
import com.liferay.translation.constants.TranslationPortletKeys;
import com.liferay.translation.security.permission.TranslationPermission;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alejandro Tardín
 */
@Component(immediate = true, service = TranslationPermission.class)
public class TranslationPermissionImpl implements TranslationPermission {

	@Override
	public boolean contains(
		PermissionChecker permissionChecker, long groupId, String languageId,
		String actionId) {

		String resourceName =
			TranslationConstants.RESOURCE_NAME + "." + languageId;

		Boolean hasPermission = _stagingPermission.hasPermission(
			permissionChecker, groupId, resourceName, 0,
			TranslationPortletKeys.TRANSLATION, actionId);

		if (hasPermission != null) {
			return hasPermission.booleanValue();
		}

		return permissionChecker.hasPermission(
			groupId, resourceName, resourceName, actionId);
	}

	@Reference
	private StagingPermission _stagingPermission;

}